@@ -579,12 +579,6 @@ def delete(job_ids: Iterable[uuid.UUID], verbose: bool):
     jointly_exhaustive=["item"],
     help="file containing table of items to transfer",
 )
-@click.option(
-    "--no-browser",
-    is_flag=True,
-    default=False,
-    help="Avoid trying to open a browser if authentication is necessary",
-)
 @click.option(
     "--verbose",
     "-v",
@@ -607,7 +601,6 @@ def transfer(
     preserve_timestamp: bool,
     item: Optional[List[Tuple[str, str, Optional[str]]]],
     items_file: Optional[str],
-    no_browser: bool,
     verbose: bool,
 ):
     """
@@ -618,7 +611,7 @@ def transfer(
         "https://actions.automate.globus.org/transfer/transfer/run"
     )
     endpoints = [source_endpoint, dest_endpoint]
-    tc = get_transfer_client(no_browser=no_browser)
+    tc = get_transfer_client()
     error_if_not_activated(tc, endpoints)
     data_access_scopes = _get_required_data_access_scopes(tc, endpoints)
     transfer_ap_scope = (
@@ -687,14 +680,8 @@ def session():
     help="Cache identity information for future operations. This is "
     "optional, as it will be done on demand if this command is not used."
 )
-@click.option(
-    "--no-browser",
-    is_flag=True,
-    default=False,
-    help="Avoid trying to open a browser if authentication is necessary",
-)
-def login(no_browser: bool):
-    user_info = get_current_user(no_browser=no_browser)
+def login():
+    user_info = get_current_user()
     click.echo(f"Logged in as {user_info['preferred_username']}")
 
 
@@ -734,8 +721,7 @@ def logout():
 
 @session.command(help="Remove Timer's authorization to use your credentials.")
 def revoke():
-    revoked = revoke_login()
-    if revoked:
+    if revoke_login():
         click.echo("Successfully revoked permission for all Timer operations.")
     else:
         click.echo("Unable to revoke login.")
